Fluid Example
===============================================================================

:download:`fluid.enaml <../../../examples/layout/advanced/fluid.enaml>`

.. literalinclude:: ../../../examples/layout/advanced/fluid.enaml
    :language: python

::

 $ enaml-run fluid.enaml

.. image:: images/fluid.png
